#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub OPEN  {}    # XXX Hackery in case the user redirects
sub CLOSE {}    # XXX STDERR/STDOUT.  This is not the behavior we want.

sub READ {}
sub READLINE {}
sub GETC {}
sub BINMODE {}

my $Original_File = 'root/usr/lib/perl5/site_perl/esmith/FormMagick/Panel/datetime.pm';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 48 root/usr/lib/perl5/site_perl/esmith/FormMagick/Panel/datetime.pm

use_ok('esmith::FormMagick::Panel::datetime');
$FM = esmith::FormMagick::Panel::datetime->new();
isa_ok($FM, 'esmith::FormMagick::Panel::datetime');
$FM->{cgi} = CGI->new;


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 74 root/usr/lib/perl5/site_perl/esmith/FormMagick/Panel/datetime.pm

is($FM->showInitial(), '', 'showInitial');
like($_STDOUT_, qr/NEW_M\/D\/Y/, ' .. new m/d/y field');
like($_STDOUT_, qr/NEW_H\/M\/S/, ' .. new h/m/s field');
like($_STDOUT_, qr/SAVE_DATE_TIME/, ' .. save date/time button');
like($_STDOUT_, qr/ENABLE_NTP/, ' .. enable NTP box');
like($_STDOUT_, qr/SAVE_NTP/, ' .. save NTP button');


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 335 root/usr/lib/perl5/site_perl/esmith/FormMagick/Panel/datetime.pm
is($FM->performAndShowResult(), '', 'performAndShowResult');

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 385 root/usr/lib/perl5/site_perl/esmith/FormMagick/Panel/datetime.pm

is($FM->verifyResult(), '', 'verifyResult');
like($_STDOUT_, qr/NEW_DATE_AND_TIME/, ' .. new date and time');


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 457 root/usr/lib/perl5/site_perl/esmith/FormMagick/Panel/datetime.pm

$FM->{cgi}->param(-name=>'day', -value=>'55');
$FM->{cgi}->param(-name=>'year', -value=>'5');
is($FM->_performSetDateTime(), '', 'performSetDateTime');
like($_STDOUT_, qr/INVALID_DAY/, ' .. invalid day check');
$FM->{cgi}->param(-name=>'day', -value=>'10');
$FM->_performSetDateTime();
like($_STDOUT_, qr/INVALID_YEAR/, ' .. invalid year check');
$FM->{cgi}->param(-name=>'year', -value=>'1984');
$FM->{cgi}->param(-name=>'hour', -value=>'60');
$FM->{cgi}->param(-name=>'minute', -value=>'90');
$FM->_performSetDateTime();
like($_STDOUT_, qr/INVALID_HOUR/, ' .. invalid hour check');
$FM->{cgi}->param(-name=>'hour', -value=>'12');
$FM->_performSetDateTime();
like($_STDOUT_, qr/INVALID_MINUTE/, ' .. invalid minute check');
$FM->{cgi}->param(-name=>'minute', -value=>'00');
$FM->{cgi}->param(-name=>'second', -value=>'00');

SKIP: {
        skip "unsafe!", 2 unless esmith::TestUtils::destruction_ok();
        is($FM->_performSetDateTime(), '', ' .. exited happily');
        like($_STDOUT_, qr/UPDATING_CLOCK/, ' .. updating clock in background');
}


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 634 root/usr/lib/perl5/site_perl/esmith/FormMagick/Panel/datetime.pm

SKIP: {
        skip "unsafe!", 3 unless esmith::TestUtils::destruction_ok();
        is($FM->_performSetTimeserver(), '', 'performSetTimeserver');
        $FM->{cgi}->param(-name=>'ntpEnabled', -value=>'on');
        $FM->{cgi}->param(-name=>'ntpServer', -value=>'time.nrc.ca');
        $FM->_performSetTimeserver();
        like($_STDOUT_, qr/SETTINGS_CHANGED/, ' .. changed settings');
        $FM->{cgi}->param(-name=>'ntpEnabled', -value=>'off');
        $FM->_performSetTimeserver();
        like($_STDOUT_, qr/SETTINGS_CHANGED/, ' .. and disabled');
}


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

